@@ -134,6 +134,13 @@ def patch_run_basic_pipeline(mocker, monkeypatch):
     return mock
 
 
+@pytest.fixture
+def mock_compare_runtime_to_buildtime_config(mocker, monkeypatch):
+    mock = mocker.Mock()
+    monkeypatch.setattr(cli, "_compare_runtime_to_buildtime_config", mock)
+    return mock
+
+
 def test_get_config(tmpdir, config):
     tmp_config = tmpdir.mkdir("klio-exec-testing").join("klio-job.yaml")
     tmp_config.write(yaml.dump(config))
@@ -189,6 +196,7 @@ def test_run_pipeline(
     mock_klio_config,
     patch_run_basic_pipeline,
 ):
+    mock_compare_runtime_to_buildtime_config.return_value = True
     runtime_conf = cli.RuntimeConfig(
         image_tag=None, direct_runner=False, update=None, blocking=None
     )
@@ -234,7 +242,6 @@ def test_run_pipeline_conf_override(
     tmpdir,
     monkeypatch,
 ):
-
     cli_inputs = []
 
     temp_dir = tmpdir.mkdir("testing123")
